hi_class

# Horndeski in the Cosmic Linear
Anisotropy Solving System

###### Einstein-Boltzmann solver for dark energy and modified gravity

#### The Science

`hi_class` implements Horndeski's theory in the modern Cosmic Linear Anisotropy Solving System. It can be used to compute any linear cosmological observable in seconds, including FRW distances, CMB, matter power and number count spectra. `hi_class` can be readily interfaced with Monte Python to test Gravity and Dark Energy models.

Horndeski is the most general scalar-tensor theory described by second-order equations of motion, and contains many well known models, including (but by no means limited to) covariant Galileons, Brans-Dicke, f(R), chameleons, k-essence and quintesssence. `hi_class` relies on a reformulation of the Effective Field Theory for Dark Energy developed by E. Bellini and I. Sawicki (see JCAP 1407 (2014) 050).

The publicly available version (`hi_class` v2.0) is presented and described in:

- `hi_class:` Horndeski in the Cosmic Linear Anisotropy Solving System
  M. Zumalacarregui, E. Bellini, I. Sawicki, J. Lesgourgues, P. Ferreira
  JCAP 1708 (2017) no.08, 019
- `hi_class:` Background Evolution, Initial Conditions and Approximation Schemes
  E. Bellini, I. Sawicki, M. Zumalacarregui
  JCAP 2002 (2020) no.02, 008

`hi_class` has been used to obtain results in a number of publications, including

- Nonlinear evolution of the BAO scale in alternative theories of gravity
  E. Bellini, M. Zumalacarregui PRD92 (2015) 063522
- Constraints on deviations from LCDM within Horndeski gravity
  E. Bellini, A. Cuesta, R. Jimenez, L. Verde JCAP 1602 (2016) 053
- Gravity at the horizon: on relativistic effects, CMB-LSS correlations and ultra-large scales in Horndeski's theory J. Renk, M. Zumalacarregui, F. Montanari JCAP 1607 (2016) 040
- The Observational Future of Cosmological Scalar-Tensor Theories
  D. Alonso, E. Bellini, P. G. Ferreira, M. Zumalacarregui PRD95 (2017) 063502
- Galileon Gravity in Light of ISW, CMB, BAO and H0 data
  J. Renk, M. Zumalacarregui, F. Montanari, A. Barreira JCAP 1710 (2017) 020
- A comparison of Einstein-Boltzmann solvers for testing General Relativity
  E. Bellini et al. PRD97 (2018) 023520

See the full list below (if your article is not listed, please contact us).

#### The Code

`hi_class` computes the cosmological predictions of alternative theories of gravity. The code solves the linear equations starting deep in the radiation era, and can compute any cosmological observable, including (but not limited to) cosmological distances, the matter power spectrum, Cosmic Microwave Background temperature and polarization, as well as their correlation with the matter distribution. The publicly available version incorporates parameterized models based on the Effective Field Theory of Dark Energy.

`hi_class` has been tested for a range of models against several codes in a dedicated paper A comparison of Einstein-Boltzmann solvers for testing General Relativity . The codes validated include EFTCAMB , COOP and the Galileon code developed by Barreira et al. (based on CAMB). The results agree within 0.1% for CMB and matter power spectra, as good as for base CLASS/CAMB using default precision parameters (at low multipoles the agreement is within 0.5%, well within cosmic variance). The achieved precision is sufficient for tests of gravity with next-generation surveys.

#### Download

`hi_class` is freely available to the scientific community. If you use it in a publication/preprint please cite at least the original CLASS paper and

- `hi_class:` Horndeski in the Cosmic Linear Anisotropy Solving System
  M. Zumalacarregui, E. Bellini, I. Sawicki, J. Lesgourgues, P. Ferreira
  JCAP 1708 (2017) 019
- `hi_class:` Background Evolution, Initial Conditions and Approximation Schemes
  E. Bellini, I. Sawicki, M. Zumalacarregui
  1909.01828

The code can be cloned from the GitHub repository or downloaded as a compressed file. To get started and find detailed information on the available models and code functionality please read the `hi_class.ini` file.

#### Resources

- `hi_class` wiki on GitHub
- `hi_class` forum on Google groups
- `hi_class` Youtube channel and introduction to the CLASS code
- Slides from the official CLASS tour
- Introductory slides for hi_class (Corfu, IFT Madrid) and Montepython (IFT Madrid)
- Materials from the School in Cosmo Tools, Aachen 2018 , including slides, exercises and lecture videos (click on clip icon).
- Notes on CLASS, `hi_class` and Monte Python (from IFT Madrid) and Monte Python (from Cosmo in the Canary Islands).
- Exercises on CLASS/`hi_class` and Montepython from IFT Cosmo Tools 17 and Montepython from Aachen Cosmo Tools 18.
- Astrophysics Source Code Library http://ascl.net/1808.010
- hi_class wrapper for CosmoSIS MCMC sampler

#### The Team

`hi_class` is being developed by

- Emilio Bellini
- Pedro G. Ferreira
- Carlos Garcia-Garcia
- Julien Lesgourgues
- Janina Renk
- Ignacy Sawicki
- Dina Traykova
- Miguel Zumalacarregui

We are very grateful to Thomas Tram for his invaluable advice and the many users who have offered suggestions, found bugs and contributed to improve the code.

#### Contact

If you are interested in using a beta version or for other inquiries about `hi_class` please contact emilio - bellini -- physics.ox.ac.uk or miguelzuma -- berkeley.edu

#### Publications using `hi_class`

`hi_class` has been used to obtain results in the following publications:

1. Nonlinear evolution of the BAO scale in alternative theories of gravity
   E. Bellini, M. Zumalacarregui PRD92 (2015) 063522
2. Constraints on deviations from LCDM within Horndeski gravity
   E. Bellini, A. Cuesta, R. Jimenez, L. Verde JCAP 1602 (2016) 053
3. Gravity at the horizon: on relativistic effects, CMB-LSS correlations and ultra-large scales in Horndeski's theory J. Renk, M. Zumalacarregui, F. Montanari JCAP 1607 (2016) 040
4. `hi_class:` Horndeski in the Cosmic Linear Anisotropy Solving System
   M. Zumalacarregui, E. Bellini, I. Sawicki, J. Lesgourgues, P. Ferreira
   JCAP 1708 (2017) 019
5. The Observational Future of Cosmological Scalar-Tensor Theories
   D. Alonso, E. Bellini, P. G. Ferreira, M. Zumalacarregui PRD95 (2017) 063502
6. Galileon Gravity in Light of ISW, CMB, BAO and H0 data
   J. Renk, M. Zumalacarregui, F. Montanari, A. Barreira JCAP 1710 (2017) 020
7. A comparison of Einstein-Boltzmann solvers for testing General Relativity
   E. Bellini et al. PRD97 (2018) 023520
8. The impact of relativistic effects on cosmological parameter estimation
   C. Lorenz, D. Alonso, P. Ferreira PRD97 (2018) 023537
9. Dark Energy after GW170817: Dead Ends and the Road Ahead
   J. M. Ezquiaga, M. Zumalacarregui Phys.Rev.Lett. 119 251304 (see Physics Viewpoint )
10. Testing (modified) gravity with 3D and tomographic cosmic shear A. Spurio Mancini, R. Reischke, V. Pettorino, B.M. Schaefer, M. Zumalacarregui MNRAS 480 (2018) 3725
11. Dark energy from α-attractors: phenomenology and observational constraints C. García-García, E. Linder, P. Ruíz-Lapuente, M. Zumalacárregui JCAP 1808 (2018) 022
12. Investigating scalar-tensor-gravity with statistics of the cosmic large-scale structure R. Reischke, A. Spurio Mancini, B. Malte Schäfer, P. Merkel 1804.02441
13. Testing Horndeski gravity as dark matter with `hi_class` A. Casalino, M. Rinaldi 1807.01995
14. Dark Energy in light of Multi-Messenger Gravitational-Wave astronomy JM Ezquiaga, M. Zumalacárregui 1807.09241
15. Gravity's Islands: Parametrizing Horndeski Stability M. Denissenya, E. Linder 1808.00013
16. No Slip CMB M. Brush, E. Linder, M. Zumalacarregui 1810.12337
17. Radiative stability and observational constraints on dark energy and modified gravity J. Noller, A. Nicola 1811.03082
18. Cosmological parameter constraints for Horndeski scalar-tensor gravity J. Noller, A. Nicola 1811.12928
19. KiDS+GAMA: Constraints on Horndeski gravity from combined large-scale structure probes A Spurio Mancini et al. 1901.03686
20. The phenomenology of beyond Horndeski gravity D. Traykova, E. Bellini, P. Ferreira 1902.10687
21. Positivity in the sky S. Melville J. Noller 1904.05874
22. Designing Horndeski and the effective fluid approach R. Arjona, W. Cardona, S. Nesseris 1904.06294
23. Modified Gravity Away from a ΛCDM Background G. Brando et al. 1904.12903
24. Alpha-attractor dark energy in view of next-generation cosmological surveys C. Garcia-Garcia et al. 1905.03753
25. Dark sector evolution in Horndeski models F. Pace et al. 1905.06795
26. The Shape Dependence of Vainshtein Screening in the Cosmic Matter Bispectrum C. Burrage, J. Dombrowski, D. Saadeh 1905.06260
27. Testing modified gravity at cosmological distances with LISA standard sirens LISA Cosmology Working Group 1906.01593
28. `hi_class:` Background Evolution, Initial Conditions and Approximation Schemes
    E. Bellini, I. Sawicki, M. Zumalacarregui
    1909.01828
29. Theoretical priors in scalar-tensor cosmologies: Thawing quintessence C. Garcia-Garcia, E. Bellini, P. Ferreira, D. Traykova, M. Zumalacarregui 1911.02868
30. Cosmological constraints on dark energy in light of gravitational wave bounds J. Noller 2001.05469
31. Gravity in the Era of Equality: Towards solutions to the Hubble problem without fine-tuned initial conditions M. Zumalacarregui 2003.06396
32. The H0 tension: ΔG_N vs. ΔN_eff G. Ballesteros, A. Notari, F. Rompineve 2004.05049
33. A larger value for H0 by an evolving gravitational constant Matteo Braglia et al. 2004.11161
34. Improvements in cosmological constraints from breaking growth degeneracy L. Perenon, S. Ilic, R. Maartens, A. de la Cruz-Dombriz 2005.00418
35. Information entropy in cosmological inference problems A. Pinho, R. Reischke, M. Teich, B. Malte Schäfer 2005.02035
36. Cross-bispectra Constraints on Modified Gravity Theories from Nancy Grace Roman Space Telescope and Rubin Observatory Legacy Survey of Space and Time C. Heinrich, O. Doré 2006.03138
37. Relativistic Corrections to the Growth of Structure in Modified Gravity G. Brando, K. Koyama, D. Wands 2006.11019
38. Constraining Scalar-Tensor Modified Gravity with Gravitational Waves and Large Scale Structure Surveys T. Baker, I. Harrison 2007.13791
39. Scalar-tensor cosmologies without screening J. Noller, L. Santoni, E. Trincherini, L. Trombetta 2008.08649
40. Early modified gravity in light of the $H_0$ tension and LSS data M. Braglia, M. Ballardini, F. Finelli and K. Koyama 2011.12934
41. Can Conformally Invariant Modified Gravity Solve The Hubble Tension? T. Abadi and E. Kovetz 2011.13853
42. Positivity Bounds on Dark Energy: When Matter Matters C. de Rham, S. Melville and J. Noller 2103.06855
43. Testing modified (Horndeski) gravity by combining intrinsic galaxy alignments with cosmic shear R. Reischke, V. Bosca, T. Tugendhat, B. Malte Schäfer 2103.01657
44. Theoretical priors in scalar-tensor cosmologies: Shift-symmetric Horndeski models D. Traykova, E. Bellini, P. G. Ferreira, C. García-García, J. Noller, M. Zumalacárregui 2103.11195
45. Fully relativistic predictions in Horndeski gravity from standard Newtonian N-body simulations G. Brando, K. Koyama, D. Wands, M. Zumalacárregui, I. Sawicki, E. Bellini 2105.04491
46. On tachyonic stability priors for dark energy R. Gsponer, J. Noller 2107.01044
47. Positivity bounds from multiple vacua and their cosmological consequences S. Melville, J. Noller 2202.01222
48. Enabling matter power spectrum emulation in beyond-ΛCDM cosmologies with COLA G. Brando, B. Fiorini, K. Koyama, H. Winther 2203.11120
49. Neutrino mass and kinetic gravity braiding degeneracies G. Garcia-Arroyo, J. L. Cervantes-Cota, U. Nucamendi 2205.05755
50. A Forecast for Large Scale Structure Constraints on Horndeski Gravity with Line Intensity Mapping B. Scott, K. Karkare, S. Bird, 2209.13029
51. Testing gravity with gravitational wave friction and gravitational slip I. Matos, E. Bellini, M. Calvão, M. Kunz, 2210.12174
52. Revisiting Vainshtein Screening for fast N-body simulations G. Brando, K. Koyama, H. Winther, 2303.09549
53. Probing Dark Energy and Modifications of Gravity with Ground-Based Millimeter-Wavelength Line Intensity Mapping A. Moradinezhad Dizgah, E. Bellini, G. Keating, 2304.08471
54. Machine learning unveils the linear matter power spectrum of modified gravity J. B. Orjuela-Quintana, S. Nesseris, D. Sapone, 2307.03643
55. Probing Early Modification of Gravity with Planck, ACT and SPT G. F. Abellán, M. Braglia, M. Ballardini, F. Finelli, V. Poulin, 2308.12345
56. Constraining dark energy with the integrated Sachs-Wolfe effect E. Seraille, J. Noller, B. Sherwin, 2401.06221
57. A simple prediction of the non-linear matter power spectrum in Brans-Dicke gravity from linear theory H. Sletmoen, H. Winther, 2403.03786
58. Modified gravity interpretation of the evolving dark energy in light of DESI data A. Chudaykin, M. Kunz, 2407.02558
59. mochi_class: Modelling Optimisation to Compute Horndeski In class M. Cataneo, E. Bellini, 2407.11968
60. Scant evidence for thawing quintessence W. Wolf, C. García-García, D. Bartlett, P. Ferreira 2408.17318
61. Constraints on dark energy and modified gravity from the BOSS Full-Shape and DESI BAO data P. Taule, M. Marinucci, G. Biselli, M. Pietroni, F. Vernizzi 2409.08971
62. Fast radio bursts as a probe of gravity on cosmological scales D. Neumann, R. Reischke, S. Hagstotz, H. Hildebrandt 2409.11163
63. Matching current observational constraints with nonminimally coupled dark energy W. Wolf, P. Ferreira, C. Garcia-Garcia 2409.17019
64. Exploring cosmological imprints of phantom crossing with dynamical dark energy in Horndeski gravity Y. Tiwari, U. Upadhyay, R. Jain 2412.00931
65. Robustness of Dark Energy Phenomenology Across Different Parameterizations W. Wolf, C. Garcia-Garcia, P. Ferreira 2502.04929
66. Preference for evolving dark energy in light of the galaxy bispectrum Z. Lu, T. Simon, P. Zhang 2503.04602
67. Modified gravity constraints with Planck ISW-lensing bispectrum A. Chudaykin, M. Kunz, J. Carron 2503.09893
68. The Cosmological Evidence for Non-Minimal Coupling W. Wolf, C. Garcia-Garcia, T. Anton, P. Ferreira 2504.07679
69. Nonlinear dynamics in Horndeski gravity: a renormalized approach to effective gravitational coupling L. Amendola, C. Bernal, R. Gannouji 2505.03999
70. Monodromic Dark Energy and DESI S. Goldstein, M. Celoria, F. Schmidt 2507.16970
71. Dark energy constraints in light of theoretical priors N. Shah, K. Koyama, J. Noller 2507.19450
72. From Dark Radiation to Dark Energy: Unified Cosmological Evolution in K-essence Models E. Moreno, J. De-Santiago 2509.25088
73. Cosmological constraints on Galileon dark energy with broken shift symmetry W. Wolf, P. Ferreira, C. Garcia-Garcia 2509.17586
74. A Dynamical Scalar Field Model for Dark Energy: Addressing the Hubble Tension and Cosmic Evolution A. Kottur, J. Mahajan, R. Dabhade 2511.10317
75. KGB-evolution: a relativistic N-body code for kinetic gravity braiding models A. Nouri-Zonoz, F. Hassani, E. Bellini, M. Kunz 2511.04676
76. Clustering in dynamical dark energy: observational constraints from DESI, CMB, and supernovae Y. Yang, Q. Wang, X. Ren, E. Saridakis, Y. Cai 2511.22478
77. Euclid preparation. Review of forecast constraints on dark energy and modified gravity Euclid Collaboration: N. Frusciante, M. Martinelli et al. 2512.09748
78. A Dynamical Scalar Field Model for Dark Energy: Addressing the Hubble Tension and Cosmic Evolution A. Kottur, J. Mahajan, R. Dabhade 2511.10317
79. Non-parametric exploration of minimally coupled gravity with phantom crossing M. Cataneo, K. Koyama 2512.13691
80. Abundance of cosmic voids in EFT of dark energy T. Takadera, S. Hirano, T. Kobayashi 2512.20171